# Whatify_Toolkit
Welcome to Whatify Toolkit

## Installation:

`pip3 install toolkit_w`
`pip3 install pytest==5.4.2`
`pip3 install allure-pytest==2.8.14`
`pip3 install s3fs==0.4.2`
`pip3 install boto3==1.10.39`

## Usage:

```
import toolkit_w as my_tool

myWhatify = my_tool.MyWhatify()

myWhatify.login(USER, PASSWORD)

```

